#!D:\bld\gdal-split_1563756732467\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==2.4.1','gdal_polygonize.py'
__requires__ = 'GDAL==2.4.1'
__import__('pkg_resources').run_script('GDAL==2.4.1', 'gdal_polygonize.py')
